Task: QA Daily Mail
====================
Description: Cloze dataset based on a missing (anonymized) entity phrase from a Daily Mail article, Hermann et al. '15. 

Link: https://arxiv.org/abs/1506.03340

Tags: #QADailyMail, #All, #Cloze

